#include <stdio.h>
#include <SDL.h>
#include <SDL_image.h>

#if defined(__EMSCRIPTEN__) || defined(__arm__)
#include <GLES2/gl2.h>
#elif defined(__LINUX__) || defined(__MINGW32__)
#include <GL/gl.h>
#elif defined(__ANDROID__)
#include <GLES/gl.h>
#endif

int main(int argc, char *argv[])
{
    SDL_version version;
    SDL_GetVersion(&version);
    printf("SDL %d.%d.%d\n", version.major, version.minor, version.patch);
    SDL_SetMainReady();
    if (SDL_Init(SDL_INIT_VIDEO) < 0)
    {
        fprintf(stderr, "SDL could not initialize! SDL_Error: %s\n", SDL_GetError());
    }
    else
    {
        SDL_Window *window = SDL_CreateWindow(
            "TARE control",
            SDL_WINDOWPOS_UNDEFINED,
            SDL_WINDOWPOS_UNDEFINED,
            640,
            480,
            SDL_WINDOW_OPENGL | SDL_WINDOW_RESIZABLE);
        if (window == NULL)
        {
            fprintf(stderr, "Could not create window! SDL_Error: %s\n", SDL_GetError());
        }
        else
        {
            SDL_ShowCursor(0);
            SDL_Renderer *renderer = SDL_CreateRenderer(window, -1, 0);
            if (renderer == NULL)
            {
                fprintf(stderr, "Could not create renderer! SDL_Error: %s\n", SDL_GetError());
            }
            else
            {
                SDL_Texture *texture = IMG_LoadTexture(renderer, "resource/Field.png");
                if (!texture)
                {
                    fprintf(stderr, "Could not load image! SDL_Error: %s\n", SDL_GetError());
                }
                else
                {
                    SDL_GL_CreateContext(window);
                    SDL_Event event;
                    int done = 0;
                    while (!done)
                    {
                        while (SDL_PollEvent(&event))
                        {
                            if (event.type == SDL_QUIT)
                            {
                                done = 1;
                            }
                        }
                        // SDL_GLContext glcontext = SDL_GL_CreateContext(window);
                        glClearColor(255, 0, 0, 1);
                        glClear(GL_COLOR_BUFFER_BIT);
                        SDL_Rect rect = {0, 0, 240, 160};
                        SDL_RenderCopy(renderer, texture, NULL, &rect);
                        SDL_RenderPresent(renderer);
                        SDL_GL_SwapWindow(window);
                        // SDL_GL_DeleteContext(glcontext);
                    }
                    SDL_DestroyTexture(texture);
                }
                SDL_DestroyRenderer(renderer);
            }
            SDL_DestroyWindow(window);
        }
    }
    SDL_Quit();
    return 0;
}
